document.addEventListener('DOMContentLoaded', function () {
    const el = document.getElementById('event-calendar');
    if (!el || typeof FullCalendar === 'undefined' || typeof EventCalendar === 'undefined') return;

    const calendar = new FullCalendar.Calendar(el, {
        initialView: 'dayGridMonth',
        events: EventCalendar.events
    });

    calendar.render();
});

document.querySelectorAll('.event-item').forEach(el => {
  const startStr = el.getAttribute('data-start'); // e.g. "2025-06-17T00:00:00+00:00"
  const endStr = el.getAttribute('data-end');     // e.g. "2025-06-18T00:00:00+00:00"
  const eventTitle = el.getAttribute('data-title');
  
  if (!startStr) return; // skip if no start time
  
  const startDate = new Date(startStr);
  const endDate = endStr ? new Date(endStr) : null;

  // Helper function to format date/time nicely
  function formatTimeRange(start, end) {
    const options = {
      hour: 'numeric', minute: 'numeric', hour12: true,
      month: 'short', day: 'numeric',
    };
    if (!end) return start.toLocaleString(undefined, options);

    return `${start.toLocaleString(undefined, options)} - ${end.toLocaleTimeString(undefined, { hour: 'numeric', minute: 'numeric', hour12: true })}`;
  }

  // Detect all-day event:
  // Start and end times are both at midnight,
  // and end is exactly one day after start.
  const isAllDay = () => {
    if (!endDate) return false;
    const startMidnight = startDate.getHours() === 0 && startDate.getMinutes() === 0 && startDate.getSeconds() === 0;
    const endMidnight = endDate.getHours() === 0 && endDate.getMinutes() === 0 && endDate.getSeconds() === 0;
    const oneDayMs = 24 * 60 * 60 * 1000;
    const diffDays = (endDate - startDate) / oneDayMs;
      console.log(diffDays);
    return startMidnight && endMidnight && diffDays === 1;
  };

  if (isAllDay()) {
    // Format as e.g. "June 17, 2025 - All Day"
    const options = { year: 'numeric', month: 'long', day: 'numeric' };
    el.textContent = `${eventTitle} — ${startDate.toLocaleDateString(undefined, options)} - All Day`;
  } else {
    el.textContent = `${eventTitle} — ${formatTimeRange(startDate, endDate)}`;
  }

});

